@@ -36,7 +36,7 @@ use base qw{ PPIx::Regexp::Token::Reference };
 use Carp qw{ confess };
 use PPIx::Regexp::Constant qw{ RE_CAPTURE_NAME @CARP_NOT };
 
-our $VERSION = '0.081';
+our $VERSION = '0.089';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -68,6 +68,14 @@ sub perl_version_introduced {
     return '5.009005';
 }
 
+sub raw_width {
+    return ( undef, undef );
+}
+
+sub width {
+    return ( undef, undef );
+}
+
 # This must be implemented by tokens which do not recognize themselves.
 # The return is a list of list references. Each list reference must
 # contain a regular expression that recognizes the token, and optionally
@@ -101,7 +109,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2021 by Thomas R. Wyant, III
+Copyright (C) 2009-2023, 2025 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
